==> chromium-93.0.4577.62.tar.xz: chromium-93.0.4577.62/chrome/browser/enterprise/connectors/file_system/signin_confirmation_modal.h <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_
#define CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_

#include "ui/views/window/dialog_delegate.h"

namespace enterprise_connectors {
class FileSystemConfirmationModal : public views::DialogDelegate {
 public:
  using Callback = base::OnceCallback<void(bool)>;
  ~FileSystemConfirmationModal() override;

  static void Show(gfx::NativeWindow context,
                   std::u16string title,
                   std::u16string message,
                   std::u16string cancel_button,
                   std::u16string accept_button,
                   Callback callback);

 private:
  FileSystemConfirmationModal(std::u16string title,
                              std::u16string message,
                              std::u16string cancel_button,
                              std::u16string accept_button,
                              Callback callback);

  // WidgetDelegate:
  ui::ModalType GetModalType() const override;
  // Title and icon.
  std::u16string GetWindowTitle() const override;
  ui::ImageModel GetWindowIcon() override;
  // Create the views::Label for the confirmation message to be displayed.
  views::View* GetContentsView() override;

  void OnCancellation() { std::move(callback_).Run(false); }
  void OnConfirmation() { std::move(callback_).Run(true); }

  const std::u16string title_, message_;
  Callback callback_;
  base::WeakPtrFactory<FileSystemConfirmationModal> weak_factory_{this};
};

}  // namespace enterprise_connectors

#endif  // CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_

==> chromium-94.0.4606.3.tar.xz: chromium-94.0.4606.3/chrome/browser/enterprise/connectors/file_system/signin_confirmation_modal.h <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_
#define CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_

#include "ui/views/window/dialog_delegate.h"

namespace enterprise_connectors {
class SigninExperienceTestObserver;

class FileSystemConfirmationModal : public views::DialogDelegate {
 public:
  using Callback = base::OnceCallback<void(bool)>;
  ~FileSystemConfirmationModal() override;

  static void Show(gfx::NativeWindow context,
                   const std::u16string& title,
                   const std::u16string& message,
                   const std::u16string& cancel_button,
                   const std::u16string& accept_button,
                   Callback callback,
                   SigninExperienceTestObserver* observer = nullptr);

 private:
  FileSystemConfirmationModal(const std::u16string& title,
                              const std::u16string& message,
                              const std::u16string& cancel_button,
                              const std::u16string& accept_button,
                              Callback callback);

  // WidgetDelegate:
  ui::ModalType GetModalType() const override;
  // Title and icon.
  std::u16string GetWindowTitle() const override;
  ui::ImageModel GetWindowIcon() override;
  // Create the views::Label for the confirmation message to be displayed.
  views::View* GetContentsView() override;

  void OnCancellation() { std::move(callback_).Run(false); }
  void OnConfirmation() { std::move(callback_).Run(true); }

  const std::u16string title_, message_;
  Callback callback_;
  base::WeakPtrFactory<FileSystemConfirmationModal> weak_factory_{this};
};

}  // namespace enterprise_connectors

#endif  // CHROME_BROWSER_ENTERPRISE_CONNECTORS_FILE_SYSTEM_SIGNIN_CONFIRMATION_MODAL_H_
